Coverage for cc_modules/cc_version_string.py: 100%

1"""

2 camcops_server/cc_modules/cc_version_string.py

3

4===============================================================================

5

6 Copyright (C) 2012, University of Cambridge, Department of Psychiatry.

7 Created by Rudolf Cardinal (rnc1001@cam.ac.uk).

8

9 This file is part of CamCOPS.

10

11 CamCOPS is free software: you can redistribute it and/or modify

12 it under the terms of the GNU General Public License as published by

13 the Free Software Foundation, either version 3 of the License, or

14 (at your option) any later version.

15

16 CamCOPS is distributed in the hope that it will be useful,

17 but WITHOUT ANY WARRANTY; without even the implied warranty of

18 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the

19 GNU General Public License for more details.

20

21 You should have received a copy of the GNU General Public License

22 along with CamCOPS. If not, see <https://www.gnu.org/licenses/>.

23

24===============================================================================

25

26**Contains CamCOPS version strings.**

27

28"""

29

30# This file MAY NOT import anything except the standard library, because it

31# is read by setup.py, which must operate in a base Python environment.

32

33# =============================================================================

34# Version constants and configuration variables read by shell scripts

35# =============================================================================

36

37# -----------------------------------------------------------------------------

38# CamCOPS server version/date

39# -----------------------------------------------------------------------------

40# When you alter the server, it is normal to change these two:

41

42 CAMCOPS_SERVER_VERSION_STRING = "2.4.21"

43 CAMCOPS_SERVER_CHANGEDATE = "2024-08-14"

44

45# +++ NOW ALSO UPDATE: +++

46#

47# documentation/source/changelog.rst

48

49

50# -----------------------------------------------------------------------------

51# Minimum tablet version permitted to upload

52# -----------------------------------------------------------------------------

53# BEWARE: it is not normal to have to change MINIMUM_TABLET_VERSION_STRING.

54# If you increase it, you may prevent old clients from uploading.

55#

56# 2022-11-30 (v2.4.15): increased from 1.14.0 to 2.0.0; 2.0.0 is the start of

57# C++ clients, so this change eliminates the old Titanium clients.

58

59 MINIMUM_TABLET_VERSION_STRING = "2.0.0"